#' @title Sotkanet Base URL
#' @description Base url for sotkanet api.
#' @param ... Arguments to be passed
#' @return sotkanet API base url
#' @references See citation("sotkanet") 
#' @author Leo Lahti \email{leo.lahti@@iki.fi}
#' @examples base_url()
#' @export
#' @keywords utilities
base_url <- function (...) {
  'https://www.sotkanet.fi/rest/1.1/'
}


